==> jc-1.4.0.tar.gz: soot/shimple/internal/SValueUnitPair.h <==
// public class soot.shimple.internal.SValueUnitPair

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 95b491953cb1508e soot_AbstractValueBox
// @dep_class 1e08829b16f399ef soot_shimple_internal_SValueUnitPair
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost
// @dep_class 8c2e64d734a5c4f4 soot_toolkits_scalar_ValueUnitPair

// header file dependencies
// @dep_header soot_toolkits_scalar_ValueUnitPair

#include "soot/toolkits/scalar/ValueUnitPair.h"

#ifndef _JC_soot_shimple_internal_SValueUnitPair_H_
#define _JC_soot_shimple_internal_SValueUnitPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Unit$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_shimple_internal_SValueUnitPair$sub_refs	_jc_soot_shimple_internal_SValueUnitPair$sub_refs;
typedef struct _jc_soot_shimple_internal_SValueUnitPair$sub_nonrefs	_jc_soot_shimple_internal_SValueUnitPair$sub_nonrefs;
typedef struct _jc_soot_shimple_internal_SValueUnitPair$refs	_jc_soot_shimple_internal_SValueUnitPair$refs;
typedef struct _jc_soot_shimple_internal_SValueUnitPair$nonrefs	_jc_soot_shimple_internal_SValueUnitPair$nonrefs;
typedef struct _jc_soot_shimple_internal_SValueUnitPair$object	_jc_soot_shimple_internal_SValueUnitPair$object;

typedef const struct _jc_soot_shimple_internal_SValueUnitPair$vmethods	_jc_soot_shimple_internal_SValueUnitPair$vmethods;
typedef const struct _jc_soot_shimple_internal_SValueUnitPair$vtable	_jc_soot_shimple_internal_SValueUnitPair$vtable;
typedef const struct _jc_soot_shimple_internal_SValueUnitPair$vtype	_jc_soot_shimple_internal_SValueUnitPair$vtype;

// Constructors
extern void _jc_soot_shimple_internal_SValueUnitPair$method$_init$93679ec5bb57a3fc(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_shimple_internal_SValueUnitPair$method$isBranchTarget$12e95e9d8aecf52a(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *);
extern jboolean _jc_soot_shimple_internal_SValueUnitPair$method$isUnitChanged$8a9ab4bd8d5c3882(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *);
extern void _jc_soot_shimple_internal_SValueUnitPair$method$setUnit$1f000555fde5d34c(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *, struct _jc_object *);
extern void _jc_soot_shimple_internal_SValueUnitPair$method$setUnitChanged$608de204d04e33e0(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_internal_SValueUnitPair$method_info$isBranchTarget$12e95e9d8aecf52a;
extern _jc_method _jc_soot_shimple_internal_SValueUnitPair$method_info$isUnitChanged$8a9ab4bd8d5c3882;
extern _jc_method _jc_soot_shimple_internal_SValueUnitPair$method_info$setUnit$1f000555fde5d34c;
extern _jc_method _jc_soot_shimple_internal_SValueUnitPair$method_info$setUnitChanged$608de204d04e33e0;

// Virtual methods structure
struct _jc_soot_shimple_internal_SValueUnitPair$vmethods {
	jboolean	(*isBranchTarget$12e95e9d8aecf52a)(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *);
	jboolean	(*isUnitChanged$8a9ab4bd8d5c3882)(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *);
	void	(*setUnit$1f000555fde5d34c)(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *, struct _jc_object *);
	void	(*setUnitChanged$608de204d04e33e0)(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *, jboolean);
};

// Vtable
struct _jc_soot_shimple_internal_SValueUnitPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractValueBox$vmethods	soot_AbstractValueBox;
	_jc_soot_toolkits_scalar_ValueUnitPair$vmethods	soot_toolkits_scalar_ValueUnitPair;
	_jc_soot_shimple_internal_SValueUnitPair$vmethods	soot_shimple_internal_SValueUnitPair;
};

// Vtype
struct _jc_soot_shimple_internal_SValueUnitPair$vtype {
	_jc_type			type;
	_jc_soot_shimple_internal_SValueUnitPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_internal_SValueUnitPair$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_internal_SValueUnitPair$refs {
    _jc_soot_shimple_internal_SValueUnitPair$sub_refs	soot_shimple_internal_SValueUnitPair;
    _jc_soot_toolkits_scalar_ValueUnitPair$sub_refs	soot_toolkits_scalar_ValueUnitPair;
    _jc_soot_AbstractValueBox$sub_refs	soot_AbstractValueBox;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_internal_SValueUnitPair$sub_nonrefs {
	jboolean	unitChanged;
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_internal_SValueUnitPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractValueBox$sub_nonrefs	soot_AbstractValueBox;
    _jc_soot_toolkits_scalar_ValueUnitPair$sub_nonrefs	soot_toolkits_scalar_ValueUnitPair;
    _jc_soot_shimple_internal_SValueUnitPair$sub_nonrefs	soot_shimple_internal_SValueUnitPair;
};

// Object instance structure
struct _jc_soot_shimple_internal_SValueUnitPair$object {
	_jc_soot_shimple_internal_SValueUnitPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_internal_SValueUnitPair$vtype	*vtype;
	_jc_soot_shimple_internal_SValueUnitPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_internal_SValueUnitPair$vtype _jc_soot_shimple_internal_SValueUnitPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_internal_SValueUnitPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_internal_SValueUnitPair$class_object;

#endif	/* _JC_soot_shimple_internal_SValueUnitPair_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/internal/SValueUnitPair.h <==
// public class soot.shimple.internal.SValueUnitPair

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 95b491953cb1508e soot_AbstractValueBox
// @dep_class 1e08829b16f399ef soot_shimple_internal_SValueUnitPair
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost
// @dep_class 8c2e64d734a5c4f4 soot_toolkits_scalar_ValueUnitPair

// header file dependencies
// @dep_header soot_toolkits_scalar_ValueUnitPair

#include "soot/toolkits/scalar/ValueUnitPair.h"

#ifndef _JC_soot_shimple_internal_SValueUnitPair_H_
#define _JC_soot_shimple_internal_SValueUnitPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Unit$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_shimple_internal_SValueUnitPair$sub_refs	_jc_soot_shimple_internal_SValueUnitPair$sub_refs;
typedef struct _jc_soot_shimple_internal_SValueUnitPair$sub_nonrefs	_jc_soot_shimple_internal_SValueUnitPair$sub_nonrefs;
typedef struct _jc_soot_shimple_internal_SValueUnitPair$refs	_jc_soot_shimple_internal_SValueUnitPair$refs;
typedef struct _jc_soot_shimple_internal_SValueUnitPair$nonrefs	_jc_soot_shimple_internal_SValueUnitPair$nonrefs;
typedef struct _jc_soot_shimple_internal_SValueUnitPair$object	_jc_soot_shimple_internal_SValueUnitPair$object;

typedef const struct _jc_soot_shimple_internal_SValueUnitPair$vmethods	_jc_soot_shimple_internal_SValueUnitPair$vmethods;
typedef const struct _jc_soot_shimple_internal_SValueUnitPair$vtable	_jc_soot_shimple_internal_SValueUnitPair$vtable;
typedef const struct _jc_soot_shimple_internal_SValueUnitPair$vtype	_jc_soot_shimple_internal_SValueUnitPair$vtype;

// Constructors
extern void _jc_soot_shimple_internal_SValueUnitPair$method$_init$93679ec5bb57a3fc(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_shimple_internal_SValueUnitPair$method$isBranchTarget$12e95e9d8aecf52a(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_shimple_internal_SValueUnitPair$method$isUnitChanged$8a9ab4bd8d5c3882(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *) _JC_JCNI_ATTR;
extern void _jc_soot_shimple_internal_SValueUnitPair$method$setUnit$1f000555fde5d34c(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_shimple_internal_SValueUnitPair$method$setUnitChanged$608de204d04e33e0(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_internal_SValueUnitPair$method_info$isBranchTarget$12e95e9d8aecf52a;
extern _jc_method _jc_soot_shimple_internal_SValueUnitPair$method_info$isUnitChanged$8a9ab4bd8d5c3882;
extern _jc_method _jc_soot_shimple_internal_SValueUnitPair$method_info$setUnit$1f000555fde5d34c;
extern _jc_method _jc_soot_shimple_internal_SValueUnitPair$method_info$setUnitChanged$608de204d04e33e0;

// Virtual methods structure
struct _jc_soot_shimple_internal_SValueUnitPair$vmethods {
	jboolean	(*isBranchTarget$12e95e9d8aecf52a)(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *) _JC_JCNI_ATTR;
	jboolean	(*isUnitChanged$8a9ab4bd8d5c3882)(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *) _JC_JCNI_ATTR;
	void	(*setUnit$1f000555fde5d34c)(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setUnitChanged$608de204d04e33e0)(_jc_env *, struct _jc_soot_shimple_internal_SValueUnitPair$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_shimple_internal_SValueUnitPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractValueBox$vmethods	soot_AbstractValueBox;
	_jc_soot_toolkits_scalar_ValueUnitPair$vmethods	soot_toolkits_scalar_ValueUnitPair;
	_jc_soot_shimple_internal_SValueUnitPair$vmethods	soot_shimple_internal_SValueUnitPair;
};

// Vtype
struct _jc_soot_shimple_internal_SValueUnitPair$vtype {
	_jc_type			type;
	_jc_soot_shimple_internal_SValueUnitPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_internal_SValueUnitPair$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_internal_SValueUnitPair$refs {
    _jc_soot_shimple_internal_SValueUnitPair$sub_refs	soot_shimple_internal_SValueUnitPair;
    _jc_soot_toolkits_scalar_ValueUnitPair$sub_refs	soot_toolkits_scalar_ValueUnitPair;
    _jc_soot_AbstractValueBox$sub_refs	soot_AbstractValueBox;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_internal_SValueUnitPair$sub_nonrefs {
	jboolean	unitChanged;
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_internal_SValueUnitPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractValueBox$sub_nonrefs	soot_AbstractValueBox;
    _jc_soot_toolkits_scalar_ValueUnitPair$sub_nonrefs	soot_toolkits_scalar_ValueUnitPair;
    _jc_soot_shimple_internal_SValueUnitPair$sub_nonrefs	soot_shimple_internal_SValueUnitPair;
};

// Object instance structure
struct _jc_soot_shimple_internal_SValueUnitPair$object {
	_jc_soot_shimple_internal_SValueUnitPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_internal_SValueUnitPair$vtype	*vtype;
	_jc_soot_shimple_internal_SValueUnitPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_internal_SValueUnitPair$vtype _jc_soot_shimple_internal_SValueUnitPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_internal_SValueUnitPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_internal_SValueUnitPair$class_object;

#endif	/* _JC_soot_shimple_internal_SValueUnitPair_H_ */
